@@ -9,7 +9,7 @@ from nvd3 import lineWithFocusChart, lineChart, \
 
 
 @register.simple_tag(name='load_chart')
-def load_chart(chart_type, series, container, x_is_date=False, x_axis_date_format="%d %b %Y", tag_script_js=True, color_category='category20'):
+def load_chart(chart_type, series, container, x_is_date=False, x_axis_format="%d %b %Y", tag_script_js=True, color_category='category20', *args, **kwargs):
     """Loads the Chart objects in the container.
 
     **usage**:
@@ -22,13 +22,13 @@ def load_chart(chart_type, series, container, x_is_date=False, x_axis_date_forma
         * ``series`` - Data set which are going to be plotted in chart.
         * ``container`` - Chart holder in html page.
         * ``x_is_date`` - if x-axis is in date format
-        * ``x_axis_date_format`` - display x-axis date in various format ie "%d %b %Y"
+        * ``x_axis_format`` - display x-axis date in various format ie "%d %b %Y"
         * ``tag_script_js`` - if show the javascript tag <script>
         * ``color_category`` - Define color category (eg. category10, category20, category20c)
     """
     if not chart_type:
         return False
-    chart = eval(chart_type)(name=container, date=x_is_date, x_axis_date_format=x_axis_date_format, color_category=color_category)
+    chart = eval(chart_type)(name=container, date=x_is_date, x_axis_format=x_axis_format, color_category=color_category, *args, **kwargs)
     #don't show the javascript tag <script>
     if not tag_script_js:
         chart.tag_script_js = False
